@@ -19,7 +19,8 @@ if (typeof ajax_helpers === 'undefined') {
             return cookieValue;
         }
 
-        function send_form(form_id, extra_data) {
+        function send_form(form_id, extra_data, timeout) {
+            if (timeout === undefined) {var timout = 0}
             var data;
             if (form_id != null) {
                 var form = $('#' + form_id);
@@ -32,11 +33,11 @@ if (typeof ajax_helpers === 'undefined') {
                     data.append(property, extra_data[property]);
                 }
             }
-            ajax_helpers.post_data(ajax_helpers.window_location, data);
+            ajax_helpers.post_data(ajax_helpers.window_location, data, timeout);
         }
 
         function contains_file(jqXHR) {
-            var content_disposition = jqXHR.getResponseHeader('Content-Disposition')
+            var content_disposition = jqXHR.getResponseHeader('Content-Disposition');
             return typeof (content_disposition) == 'string' && content_disposition.indexOf('attachment') > -1;
         }
 
@@ -45,11 +46,11 @@ if (typeof ajax_helpers === 'undefined') {
         }
 
         function download_file(jqXHR, response) {
-            var content_disposition = jqXHR.getResponseHeader('Content-Disposition')
-            var blob = new Blob([response], {type: "octet/stream"})
+            var content_disposition = jqXHR.getResponseHeader('Content-Disposition');
+            var blob = new Blob([response], {type: "octet/stream"});
             var download_url = window.URL.createObjectURL(blob);
             if (navigator.msSaveOrOpenBlob) {
-                var filename = content_disposition.split('"')[1]
+                var filename = content_disposition.split('"')[1];
                 navigator.msSaveOrOpenBlob(blob, filename);
                 alert('your file has downloaded');
             } else {
@@ -64,7 +65,8 @@ if (typeof ajax_helpers === 'undefined') {
             }
         }
 
-        function post_data(url, data) {
+        function post_data(url, data, timeout) {
+            if (timeout === undefined) {var timout = 0}
             $.ajax(
                 {
                     url: url,
@@ -74,11 +76,13 @@ if (typeof ajax_helpers === 'undefined') {
                     cache: false,
                     contentType: false,
                     processData: false,
-                    success: from_django
+                    success: from_django,
+                    timeout: timout
                 })
         }
 
-        function post_json(ajax_data) {
+        function post_json(ajax_data, timeout) {
+            if (timeout === undefined) {var timout = 0}
             var url, data, success
             if (typeof(ajax_data) === 'object'){
                 if (ajax_data.url !== undefined){
@@ -108,7 +112,8 @@ if (typeof ajax_helpers === 'undefined') {
                     contentType: 'application/json',
                     beforeSend: add_CSRF,
                     cache: false,
-                    success: success
+                    success: success,
+                    timout: timout,
                 });
         }
 
@@ -204,6 +209,23 @@ if (typeof ajax_helpers === 'undefined') {
             }
         }
 
+        function set_ajax_busy(status, pointer_wait){
+            if (typeof pointer_wait === 'undefined'){
+                var pointer_wait = false
+            }
+            if (status === true){
+                ajax_helpers.ajax_busy = true
+                if (pointer_wait){
+                    $("html").addClass("wait")
+                }
+            } else {
+                ajax_helpers.ajax_busy = false
+                if (pointer_wait){
+                    $("html").removeClass("wait")
+                }
+            }
+        }
+
         var command_functions = {
 
             html: function (command) {
@@ -226,6 +248,11 @@ if (typeof ajax_helpers === 'undefined') {
             }
         };
 
+        $(document).ajaxError(function(){
+            $("html").removeClass("wait");
+            ajax_helpers.ajax_busy = false
+        });
+
         return {
             getCookie,
             get_content,
@@ -237,6 +264,7 @@ if (typeof ajax_helpers === 'undefined') {
             process_commands,
             tooltip,
             ajax_busy,
+            set_ajax_busy,
         }
     }()
 }
